==> openconfig-models-15.1.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/aaa/rev200730/aaa/authentication/top/AuthenticationBuilder.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.top;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.AaaAuthenticationAdminTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.AaaAuthenticationUserTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.admin.top.AdminUser;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.top.authentication.Config;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.top.authentication.State;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.user.top.Users;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link AuthenticationBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     AuthenticationBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new AuthenticationBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of AuthenticationBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see AuthenticationBuilder
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class AuthenticationBuilder implements Builder<Authentication> {

    private AdminUser _adminUser;
    private Config _config;
    private State _state;
    private Users _users;


    Map<Class<? extends Augmentation<Authentication>>, Augmentation<Authentication>> augmentation = Collections.emptyMap();

    public AuthenticationBuilder() {
    }
    
    
    
    public AuthenticationBuilder(AaaAuthenticationAdminTop arg) {
        this._adminUser = arg.getAdminUser();
    }
    
    public AuthenticationBuilder(AaaAuthenticationUserTop arg) {
        this._users = arg.getUsers();
    }

    public AuthenticationBuilder(Authentication base) {
        Map<Class<? extends Augmentation<Authentication>>, Augmentation<Authentication>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._adminUser = base.getAdminUser();
        this._config = base.getConfig();
        this._state = base.getState();
        this._users = base.getUsers();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>AaaAuthenticationAdminTop</li>
     * <li>AaaAuthenticationUserTop</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof AaaAuthenticationAdminTop) {
            this._adminUser = ((AaaAuthenticationAdminTop)arg).getAdminUser();
            isValidArg = true;
        }
        if (arg instanceof AaaAuthenticationUserTop) {
            this._users = ((AaaAuthenticationUserTop)arg).getUsers();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[AaaAuthenticationAdminTop, AaaAuthenticationUserTop]");
    }

    public AdminUser getAdminUser() {
        return _adminUser;
    }
    
    public Config getConfig() {
        return _config;
    }
    
    public State getState() {
        return _state;
    }
    
    public Users getUsers() {
        return _users;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Authentication>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public AuthenticationBuilder setAdminUser(final AdminUser value) {
        this._adminUser = value;
        return this;
    }
    
    public AuthenticationBuilder setConfig(final Config value) {
        this._config = value;
        return this;
    }
    
    public AuthenticationBuilder setState(final State value) {
        this._state = value;
        return this;
    }
    
    public AuthenticationBuilder setUsers(final Users value) {
        this._users = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public AuthenticationBuilder addAugmentation(Augmentation<Authentication> augmentation) {
        Class<? extends Augmentation<Authentication>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public AuthenticationBuilder removeAugmentation(Class<? extends Augmentation<Authentication>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Authentication build() {
        return new AuthenticationImpl(this);
    }

    private static final class AuthenticationImpl
        extends AbstractAugmentable<Authentication>
        implements Authentication {
    
        private final AdminUser _adminUser;
        private final Config _config;
        private final State _state;
        private final Users _users;
    
        AuthenticationImpl(AuthenticationBuilder base) {
            super(base.augmentation);
            this._adminUser = base.getAdminUser();
            this._config = base.getConfig();
            this._state = base.getState();
            this._users = base.getUsers();
        }
    
        @Override
        public AdminUser getAdminUser() {
            return _adminUser;
        }
        
        @Override
        public Config getConfig() {
            return _config;
        }
        
        @Override
        public State getState() {
            return _state;
        }
        
        @Override
        public Users getUsers() {
            return _users;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = Authentication.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return Authentication.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return Authentication.bindingToString(this);
        }
    }
}

==> openconfig-models-15.3.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/aaa/rev200730/aaa/authentication/top/AuthenticationBuilder.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.top;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.AaaAuthenticationAdminTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.AaaAuthenticationUserTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.admin.top.AdminUser;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.top.authentication.Config;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.top.authentication.State;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.aaa.rev200730.aaa.authentication.user.top.Users;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link Authentication} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     Authentication createAuthentication(int fooXyzzy, int barBaz) {
 *         return new AuthenticationBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of Authentication, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see Authentication
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class AuthenticationBuilder implements Builder<Authentication> {

    private AdminUser _adminUser;
    private Config _config;
    private State _state;
    private Users _users;


    Map<Class<? extends Augmentation<Authentication>>, Augmentation<Authentication>> augmentation = Collections.emptyMap();

    public AuthenticationBuilder() {
    }
    
    
    
    public AuthenticationBuilder(AaaAuthenticationAdminTop arg) {
        this._adminUser = arg.getAdminUser();
    }
    
    public AuthenticationBuilder(AaaAuthenticationUserTop arg) {
        this._users = arg.getUsers();
    }

    public AuthenticationBuilder(Authentication base) {
        Map<Class<? extends Augmentation<Authentication>>, Augmentation<Authentication>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._adminUser = base.getAdminUser();
        this._config = base.getConfig();
        this._state = base.getState();
        this._users = base.getUsers();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>AaaAuthenticationAdminTop</li>
     * <li>AaaAuthenticationUserTop</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof AaaAuthenticationAdminTop) {
            this._adminUser = ((AaaAuthenticationAdminTop)arg).getAdminUser();
            isValidArg = true;
        }
        if (arg instanceof AaaAuthenticationUserTop) {
            this._users = ((AaaAuthenticationUserTop)arg).getUsers();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[AaaAuthenticationAdminTop, AaaAuthenticationUserTop]");
    }

    public AdminUser getAdminUser() {
        return _adminUser;
    }
    
    public Config getConfig() {
        return _config;
    }
    
    public State getState() {
        return _state;
    }
    
    public Users getUsers() {
        return _users;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Authentication>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public AuthenticationBuilder setAdminUser(final AdminUser value) {
        this._adminUser = value;
        return this;
    }
    
    public AuthenticationBuilder setConfig(final Config value) {
        this._config = value;
        return this;
    }
    
    public AuthenticationBuilder setState(final State value) {
        this._state = value;
        return this;
    }
    
    public AuthenticationBuilder setUsers(final Users value) {
        this._users = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public AuthenticationBuilder addAugmentation(Augmentation<Authentication> augmentation) {
        Class<? extends Augmentation<Authentication>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public AuthenticationBuilder removeAugmentation(Class<? extends Augmentation<Authentication>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Authentication build() {
        return new AuthenticationImpl(this);
    }

    private static final class AuthenticationImpl
        extends AbstractAugmentable<Authentication>
        implements Authentication {
    
        private final AdminUser _adminUser;
        private final Config _config;
        private final State _state;
        private final Users _users;
    
        AuthenticationImpl(AuthenticationBuilder base) {
            super(base.augmentation);
            this._adminUser = base.getAdminUser();
            this._config = base.getConfig();
            this._state = base.getState();
            this._users = base.getUsers();
        }
    
        @Override
        public AdminUser getAdminUser() {
            return _adminUser;
        }
        
        @Override
        public Config getConfig() {
            return _config;
        }
        
        @Override
        public State getState() {
            return _state;
        }
        
        @Override
        public Users getUsers() {
            return _users;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = Authentication.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return Authentication.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return Authentication.bindingToString(this);
        }
    }
}
